@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -1405,6 +1405,7 @@ enum : StringId
     STR_INVALID_RIDE_TYPE = 5764,
     STR_CANT_EDIT_INVALID_RIDE_TYPE = 5765,
     STR_HUNGARIAN_FORINT = 5766,
+    STR_POLISH_ZLOTY = 7012,
     STR_MULTIPLAYER_CONNECTED_CHAT_HINT = 5782,
     STR_CANT_RENAME_GROUP = 5785,
     STR_INVALID_GROUP_NAME = 5786,
@@ -1575,6 +1576,7 @@ enum : StringId
     STR_UNKNOWN_RIDE = 6375,
 
     STR_MULTIPLAYER_RECEIVING_OBJECTS_LIST = 6378,
+    STR_MULTIPLAYER_RECEIVING_SCRIPTS = 7009,
 
     STR_MULTIPLAYER_RECEIVED_INVALID_DATA = 6379,
 
@@ -1600,6 +1602,10 @@ enum : StringId
     STR_THIS_WILL_TAKE_A_FEW_MINUTES = 6407,
     STR_INSTALL_INNOEXTRACT = 6408,
     STR_NOT_THE_GOG_INSTALLER = 6409,
+    STR_OWN_ON_STEAM = 7014,
+    STR_PLEASE_CLOSE_STEAM = 7015,
+    STR_WAIT_FOR_STEAM_DOWNLOAD = 7016,
+    STR_QUIT_ONBOARDING = 7017,
 
     STR_TILE_INSPECTOR_TOGGLE_INVISIBILITY_TIP = 6436,
 
@@ -1757,6 +1763,11 @@ enum : StringId
     // Window: Error
     STR_AUDIO_FILE_TRUNCATED = 7003,
 
+    STR_REPLAY_FILE_NOT_FOUND = 7010,
+    STR_REPLAY_NOT_STARTED = 7011,
+
+    STR_ACTION_PATH_DRAG_AREA = 7013,
+
     // Have to include resource strings (from scenarios and objects) for the time being now that language is partially working
     /* MAX_STR_COUNT = 32768 */ // MAX_STR_COUNT - upper limit for number of strings, not the current count strings
 };
