@@ -1,5 +1,5 @@
 /*****************************************************************************
- * Copyright (c) 2014-2025 OpenRCT2 developers
+ * Copyright (c) 2014-2026 OpenRCT2 developers
  *
  * For a complete list of all authors, please refer to contributors.md
  * Interested in contributing? Visit https://github.com/OpenRCT2/OpenRCT2
@@ -13,6 +13,7 @@
 #include "../Context.h"
 #include "../GameState.h"
 #include "../OpenRCT2.h"
+#include "../core/Guard.hpp"
 #include "../core/Money.hpp"
 #include "../core/UnitConversion.h"
 #include "../profiling/Profiling.h"
@@ -163,7 +164,7 @@ static void RideRatingsApplyPenaltyLateralGs(RideRating::Tuple& ratings, const R
 
 void RideRating::ResetUpdateStates()
 {
-    RideRating::UpdateState nullState{};
+    UpdateState nullState{};
     nullState.State = RIDE_RATINGS_STATE_FIND_NEXT_RIDE;
 
     auto& updateStates = getGameState().rideRatingUpdateStates;
@@ -178,9 +179,9 @@ void RideRating::ResetUpdateStates()
  */
 void RideRating::UpdateRide(const Ride& ride)
 {
-    RideRating::UpdateState state;
     if (ride.status != RideStatus::closed)
     {
+        UpdateState state;
         state.CurrentRide = ride.id;
         state.State = RIDE_RATINGS_STATE_INITIALISE;
         while (state.State != RIDE_RATINGS_STATE_FIND_NEXT_RIDE)
@@ -272,7 +273,8 @@ static bool ShouldSkipRatingCalculation(const Ride& ride)
 
 static RideId GetNextRideToUpdate(RideId currentRide)
 {
-    auto rm = GetRideManager();
+    auto& gameState = getGameState();
+    auto rm = RideManager(gameState);
     if (rm.size() == 0)
     {
         return RideId::GetNull();
@@ -340,6 +342,7 @@ static void ride_ratings_update_state_1(RideRating::UpdateState& state)
         state.ProximityScores[i] = 0;
     }
     state.AmountOfBrakes = 0;
+    state.amountOfBoosters = 0;
     state.AmountOfReversers = 0;
     state.State = RIDE_RATINGS_STATE_2;
     state.StationFlags = 0;
@@ -384,10 +387,10 @@ static void ride_ratings_update_state_2(RideRating::UpdateState& state)
                 continue;
         }
 
-        if (trackType == TrackElemType::None
+        if (trackType == TrackElemType::none
             || (tileElement->AsTrack()->GetSequenceIndex() == 0 && trackType == tileElement->AsTrack()->GetTrackType()))
         {
-            if (trackType == TrackElemType::EndStation)
+            if (trackType == TrackElemType::endStation)
             {
                 auto entranceIndex = tileElement->AsTrack()->GetStationIndex();
                 state.StationFlags &= ~RIDE_RATING_STATION_FLAG_NO_ENTRANCE;
@@ -489,7 +492,7 @@ static void ride_ratings_update_state_5(RideRating::UpdateState& state)
                 continue;
         }
 
-        if (trackType == TrackElemType::None || trackType == tileElement->AsTrack()->GetTrackType())
+        if (trackType == TrackElemType::none || trackType == tileElement->AsTrack()->GetTrackType())
         {
             ride_ratings_score_close_proximity(state, tileElement);
 
@@ -549,7 +552,7 @@ static void ride_ratings_begin_proximity_loop(RideRating::UpdateState& state)
 
             auto location = station.GetStart();
             state.Proximity = location;
-            state.ProximityTrackType = TrackElemType::None;
+            state.ProximityTrackType = TrackElemType::none;
             state.ProximityStart = location;
             return;
         }
@@ -658,8 +661,8 @@ static void ride_ratings_score_close_proximity_loops_helper(RideRating::UpdateSt
                 if (zDiff >= 0 && zDiff <= 16)
                 {
                     proximity_score_increment(state, PROXIMITY_TRACK_THROUGH_VERTICAL_LOOP);
-                    if (tileElement->AsTrack()->GetTrackType() == TrackElemType::LeftVerticalLoop
-                        || tileElement->AsTrack()->GetTrackType() == TrackElemType::RightVerticalLoop)
+                    if (tileElement->AsTrack()->GetTrackType() == TrackElemType::leftVerticalLoop
+                        || tileElement->AsTrack()->GetTrackType() == TrackElemType::rightVerticalLoop)
                     {
                         proximity_score_increment(state, PROXIMITY_INTERSECTING_VERTICAL_LOOP);
                     }
@@ -676,7 +679,7 @@ static void ride_ratings_score_close_proximity_loops_helper(RideRating::UpdateSt
 static void ride_ratings_score_close_proximity_loops(RideRating::UpdateState& state, TileElement* inputTileElement)
 {
     auto trackType = inputTileElement->AsTrack()->GetTrackType();
-    if (trackType == TrackElemType::LeftVerticalLoop || trackType == TrackElemType::RightVerticalLoop)
+    if (trackType == TrackElemType::leftVerticalLoop || trackType == TrackElemType::rightVerticalLoop)
     {
         ride_ratings_score_close_proximity_loops_helper(state, { state.Proximity, inputTileElement });
 
@@ -770,7 +773,7 @@ static void ride_ratings_score_close_proximity(RideRating::UpdateState& state, T
             case TileElementType::Track:
             {
                 auto trackType = tileElement->AsTrack()->GetTrackType();
-                if (trackType == TrackElemType::LeftVerticalLoop || trackType == TrackElemType::RightVerticalLoop)
+                if (trackType == TrackElemType::leftVerticalLoop || trackType == TrackElemType::rightVerticalLoop)
                 {
                     int32_t sequence = tileElement->AsTrack()->GetSequenceIndex();
                     if (sequence == 3 || sequence == 6)
@@ -862,18 +865,12 @@ static void ride_ratings_score_close_proximity(RideRating::UpdateState& state, T
     ride_ratings_score_close_proximity_in_direction(state, inputTileElement, (direction - 1) & 3);
     ride_ratings_score_close_proximity_loops(state, inputTileElement);
 
-    switch (state.ProximityTrackType)
-    {
-        case TrackElemType::Brakes:
-            state.AmountOfBrakes++;
-            break;
-        case TrackElemType::LeftReverser:
-        case TrackElemType::RightReverser:
-            state.AmountOfReversers++;
-            break;
-        default:
-            break;
-    }
+    if (TrackTypeIsBrakes(state.ProximityTrackType))
+        state.AmountOfBrakes++;
+    else if (TrackTypeIsBooster(state.ProximityTrackType))
+        state.amountOfBoosters++;
+    else if (TrackTypeIsReverser(state.ProximityTrackType))
+        state.AmountOfReversers++;
 }
 
 static void RideRatingsCalculate(RideRating::UpdateState& state, Ride& ride)
@@ -892,7 +889,7 @@ static void RideRatingsCalculate(RideRating::UpdateState& state, Ride& ride)
             break;
         case RatingsCalculationType::Stall:
             ride.upkeepCost = RideComputeUpkeep(state, ride);
-            ride.windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_INCOME;
+            ride.windowInvalidateFlags.set(RideInvalidateFlag::income);
             // Exit ratings
             return;
     }
@@ -901,7 +898,8 @@ static void RideRatingsCalculate(RideRating::UpdateState& state, Ride& ride)
     SetUnreliabilityFactor(ride);
 
     const auto shelteredEighths = GetNumOfShelteredEighths(ride);
-    ride.shelteredEighths = (rrd.RideShelter == -1) ? shelteredEighths.TotalShelteredEighths : rrd.RideShelter;
+    ride.shelteredEighths = (rrd.RideShelter == kDynamicRideShelterRating) ? shelteredEighths.TotalShelteredEighths
+                                                                           : rrd.RideShelter;
 
     RideRating::Tuple ratings = rrd.BaseRatings;
     // Apply Modifiers
@@ -1055,11 +1053,11 @@ static void RideRatingsCalculate(RideRating::UpdateState& state, Ride& ride)
     if (ride.ratings != ratings)
     {
         ride.ratings = ratings;
-        ride.windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_RATINGS;
+        ride.windowInvalidateFlags.set(RideInvalidateFlag::ratings);
     }
 
     ride.upkeepCost = RideComputeUpkeep(state, ride);
-    ride.windowInvalidateFlags |= RIDE_INVALIDATE_RIDE_INCOME;
+    ride.windowInvalidateFlags.set(RideInvalidateFlag::income);
 
 #ifdef ORIGINAL_RATINGS
     if (!ride.ratings.isNull())
@@ -1110,21 +1108,7 @@ static void RideRatingsCalculateValue(Ride& ride)
     {
         int32_t months, multiplier, divisor, summand;
     };
-    static const Row ageTableNew[] = {
-        { 5, 3, 2, 0 },       // 1.5x
-        { 13, 6, 5, 0 },      // 1.2x
-        { 40, 1, 1, 0 },      // 1x
-        { 64, 3, 4, 0 },      // 0.75x
-        { 88, 9, 16, 0 },     // 0.56x
-        { 104, 27, 64, 0 },   // 0.42x
-        { 120, 81, 256, 0 },  // 0.32x
-        { 128, 81, 512, 0 },  // 0.16x
-        { 200, 81, 1024, 0 }, // 0.08x
-        { 200, 9, 16, 0 },    // 0.56x "easter egg"
-    };
-
-#ifdef ORIGINAL_RATINGS
-    static const Row ageTableOld[] = {
+    static constexpr auto kAgeTable = std::to_array<Row>({
         { 5, 1, 1, 30 },      // +30
         { 13, 1, 1, 10 },     // +10
         { 40, 1, 1, 0 },      // 1x
@@ -1135,8 +1119,7 @@ static void RideRatingsCalculateValue(Ride& ride)
         { 128, 81, 512, 0 },  // 0.16x
         { 200, 81, 1024, 0 }, // 0.08x
         { 200, 9, 16, 0 },    // 0.56x "easter egg"
-    };
-#endif
+    });
 
     if (!RideHasRatings(ride))
     {
@@ -1155,15 +1138,7 @@ static void RideRatingsCalculateValue(Ride& ride)
         monthsOld = ride.getAge();
     }
 
-    const Row* ageTable = ageTableNew;
-    size_t tableSize = std::size(ageTableNew);
-
-#ifdef ORIGINAL_RATINGS
-    ageTable = ageTableOld;
-    tableSize = std::size(ageTableOld);
-#endif
-
-    Row lastRow = ageTable[tableSize - 1];
+    Row lastRow = kAgeTable[kAgeTable.size() - 1];
 
     // Ride is older than oldest age in the table?
     if (monthsOld >= lastRow.months)
@@ -1173,10 +1148,8 @@ static void RideRatingsCalculateValue(Ride& ride)
     else
     {
         // Find the first hit in the table that matches this ride's age
-        for (size_t it = 0; it < tableSize; it++)
+        for (const Row& curr : kAgeTable)
         {
-            Row curr = ageTable[it];
-
             if (monthsOld < curr.months)
             {
                 value = (value * curr.multiplier) / curr.divisor + curr.summand;
@@ -1186,7 +1159,8 @@ static void RideRatingsCalculateValue(Ride& ride)
     }
 
     // Other ride of same type penalty
-    const auto& rideManager = GetRideManager();
+    const auto& gameState = getGameState();
+    const auto& rideManager = RideManager(gameState);
     auto rideType = ride.type;
     auto otherRidesOfSameType = std::count_if(rideManager.begin(), rideManager.end(), [rideType](const Ride& r) {
         return r.status == RideStatus::open && r.type == rideType;
@@ -1235,6 +1209,9 @@ static money64 RideComputeUpkeep(RideRating::UpdateState& state, const Ride& rid
     // Add maintenance cost for brake track pieces
     upkeep += 20 * state.AmountOfBrakes;
 
+    // Add maintenance cost for booster track pieces
+    upkeep += 80 * state.amountOfBoosters;
+
     // these seem to be adhoc adjustments to a ride's upkeep/cost, times
     // various variables set on the ride itself.
 
@@ -1358,16 +1335,17 @@ static void RideRatingsApplyIntensityPenalty(RideRating::Tuple& ratings)
  */
 static void SetUnreliabilityFactor(Ride& ride)
 {
+    const auto& rtd = ride.getRideTypeDescriptor();
     // Special unreliability for a few ride types
-    if (ride.type == RIDE_TYPE_COMPACT_INVERTED_COASTER && ride.mode == RideMode::reverseInclineLaunchedShuttle)
+    if (rtd.HasFlag(RtdFlag::reverseInclineLaunchAffectsReliability) && ride.mode == RideMode::reverseInclineLaunchedShuttle)
     {
         ride.unreliabilityFactor += 10;
     }
-    else if (ride.type == RIDE_TYPE_LOOPING_ROLLER_COASTER && ride.isPoweredLaunched())
+    else if (rtd.HasFlag(RtdFlag::poweredLaunchAffectsReliability) && ride.isPoweredLaunched())
     {
         ride.unreliabilityFactor += 5;
     }
-    else if (ride.type == RIDE_TYPE_CHAIRLIFT)
+    else if (rtd.HasFlag(RtdFlag::runningSpeedAffectsReliability))
     {
         ride.unreliabilityFactor += (ride.speed * 2);
     }
